[−][src]Enum unicode_types::sutton_signwriting::SuttonSignWriting
An enum to represent all characters in the SuttonSignWriting block.
Variants
SignwritingHandDashFistIndex\u{1d800}: '𝠀'
SignwritingHandDashCircleIndex\u{1d801}: '𝠁'
SignwritingHandDashCupIndex\u{1d802}: '𝠂'
SignwritingHandDashOvalIndex\u{1d803}: '𝠃'
SignwritingHandDashHingeIndex\u{1d804}: '𝠄'
SignwritingHandDashAngleIndex\u{1d805}: '𝠅'
SignwritingHandDashFistIndexBent\u{1d806}: '𝠆'
SignwritingHandDashCircleIndexBent\u{1d807}: '𝠇'
SignwritingHandDashFistThumbUnderIndexBent\u{1d808}: '𝠈'
SignwritingHandDashFistIndexRaisedKnuckle\u{1d809}: '𝠉'
SignwritingHandDashFistIndexCupped\u{1d80a}: '𝠊'
SignwritingHandDashFistIndexHinged\u{1d80b}: '𝠋'
SignwritingHandDashFistIndexHingedLow\u{1d80c}: '𝠌'
SignwritingHandDashCircleIndexHinge\u{1d80d}: '𝠍'
SignwritingHandDashFistIndexMiddle\u{1d80e}: '𝠎'
SignwritingHandDashCircleIndexMiddle\u{1d80f}: '𝠏'
SignwritingHandDashFistIndexMiddleBent\u{1d810}: '𝠐'
SignwritingHandDashFistIndexMiddleRaisedKnuckles\u{1d811}: '𝠑'
SignwritingHandDashFistIndexMiddleHinged\u{1d812}: '𝠒'
SignwritingHandDashFistIndexUpMiddleHinged\u{1d813}: '𝠓'
SignwritingHandDashFistIndexHingedMiddleUp\u{1d814}: '𝠔'
SignwritingHandDashFistIndexMiddleConjoined\u{1d815}: '𝠕'
SignwritingHandDashFistIndexMiddleConjoinedIndexBent\u{1d816}: '𝠖'
SignwritingHandDashFistIndexMiddleConjoinedMiddleBent\u{1d817}: '𝠗'
SignwritingHandDashFistIndexMiddleConjoinedCupped\u{1d818}: '𝠘'
SignwritingHandDashFistIndexMiddleConjoinedHinged\u{1d819}: '𝠙'
SignwritingHandDashFistIndexMiddleCrossed\u{1d81a}: '𝠚'
SignwritingHandDashCircleIndexMiddleCrossed\u{1d81b}: '𝠛'
SignwritingHandDashFistMiddleBentOverIndex\u{1d81c}: '𝠜'
SignwritingHandDashFistIndexBentOverMiddle\u{1d81d}: '𝠝'
SignwritingHandDashFistIndexMiddleThumb\u{1d81e}: '𝠞'
SignwritingHandDashCircleIndexMiddleThumb\u{1d81f}: '𝠟'
SignwritingHandDashFistIndexMiddleStraightThumbBent\u{1d820}: '𝠠'
SignwritingHandDashFistIndexMiddleBentThumbStraight\u{1d821}: '𝠡'
SignwritingHandDashFistIndexMiddleThumbBent\u{1d822}: '𝠢'
SignwritingHandDashFistIndexMiddleHingedSpreadThumbSide\u{1d823}: '𝠣'
SignwritingHandDashFistIndexUpMiddleHingedThumbSide\u{1d824}: '𝠤'
SignwritingHandDashFistIndexUpMiddleHingedThumbConjoined\u{1d825}: '𝠥'
SignwritingHandDashFistIndexHingedMiddleUpThumbSide\u{1d826}: '𝠦'
SignwritingHandDashFistIndexMiddleUpSpreadThumbForward\u{1d827}: '𝠧'
SignwritingHandDashFistIndexMiddleThumbCupped\u{1d828}: '𝠨'
SignwritingHandDashFistIndexMiddleThumbCircled\u{1d829}: '𝠩'
SignwritingHandDashFistIndexMiddleThumbHooked\u{1d82a}: '𝠪'
SignwritingHandDashFistIndexMiddleThumbHinged\u{1d82b}: '𝠫'
SignwritingHandDashFistThumbBetweenIndexMiddleStraight\u{1d82c}: '𝠬'
SignwritingHandDashFistIndexMiddleConjoinedThumbSide\u{1d82d}: '𝠭'
SignwritingHandDashFistIndexMiddleConjoinedThumbSideConjoined\u{1d82e}: '𝠮'
SignwritingHandDashFistIndexMiddleConjoinedThumbSideBent\u{1d82f}: '𝠯'
SignwritingHandDashFistMiddleThumbHookedIndexUp\u{1d830}: '𝠰'
SignwritingHandDashFistIndexThumbHookedMiddleUp\u{1d831}: '𝠱'
SignwritingHandDashFistIndexMiddleConjoinedHingedThumbSide\u{1d832}: '𝠲'
SignwritingHandDashFistIndexMiddleCrossedThumbSide\u{1d833}: '𝠳'
SignwritingHandDashFistIndexMiddleConjoinedThumbForward\u{1d834}: '𝠴'
SignwritingHandDashFistIndexMiddleConjoinedCuppedThumbForward\u{1d835}: '𝠵'
SignwritingHandDashFistMiddleThumbCuppedIndexUp\u{1d836}: '𝠶'
SignwritingHandDashFistIndexThumbCuppedMiddleUp\u{1d837}: '𝠷'
SignwritingHandDashFistMiddleThumbCircledIndexUp\u{1d838}: '𝠸'
SignwritingHandDashFistMiddleThumbCircledIndexHinged\u{1d839}: '𝠹'
SignwritingHandDashFistIndexThumbAngledOutMiddleUp\u{1d83a}: '𝠺'
SignwritingHandDashFistIndexThumbAngledInMiddleUp\u{1d83b}: '𝠻'
SignwritingHandDashFistIndexThumbCircledMiddleUp\u{1d83c}: '𝠼'
SignwritingHandDashFistIndexMiddleThumbConjoinedHinged\u{1d83d}: '𝠽'
SignwritingHandDashFistIndexMiddleThumbAngledOut\u{1d83e}: '𝠾'
SignwritingHandDashFistIndexMiddleThumbAngled\u{1d83f}: '𝠿'
SignwritingHandDashFistMiddleThumbAngledOutIndexUp\u{1d840}: '𝡀'
SignwritingHandDashFistMiddleThumbAngledOutIndexCrossed\u{1d841}: '𝡁'
SignwritingHandDashFistMiddleThumbAngledIndexUp\u{1d842}: '𝡂'
SignwritingHandDashFistIndexThumbHookedMiddleHinged\u{1d843}: '𝡃'
SignwritingHandDashFlatFourFingers\u{1d844}: '𝡄'
SignwritingHandDashFlatFourFingersBent\u{1d845}: '𝡅'
SignwritingHandDashFlatFourFingersHinged\u{1d846}: '𝡆'
SignwritingHandDashFlatFourFingersConjoined\u{1d847}: '𝡇'
SignwritingHandDashFlatFourFingersConjoinedSplit\u{1d848}: '𝡈'
SignwritingHandDashClawFourFingersConjoined\u{1d849}: '𝡉'
SignwritingHandDashFistFourFingersConjoinedBent\u{1d84a}: '𝡊'
SignwritingHandDashHingeFourFingersConjoined\u{1d84b}: '𝡋'
SignwritingHandDashFlatFiveFingersSpread\u{1d84c}: '𝡌'
SignwritingHandDashFlatHeelFiveFingersSpread\u{1d84d}: '𝡍'
SignwritingHandDashFlatFiveFingersSpreadFourBent\u{1d84e}: '𝡎'
SignwritingHandDashFlatHeelFiveFingersSpreadFourBent\u{1d84f}: '𝡏'
SignwritingHandDashFlatFiveFingersSpreadBent\u{1d850}: '𝡐'
SignwritingHandDashFlatHeelFiveFingersSpreadBent\u{1d851}: '𝡑'
SignwritingHandDashFlatFiveFingersSpreadThumbForward\u{1d852}: '𝡒'
SignwritingHandDashCupFiveFingersSpread\u{1d853}: '𝡓'
SignwritingHandDashCupFiveFingersSpreadOpen\u{1d854}: '𝡔'
SignwritingHandDashHingeFiveFingersSpreadOpen\u{1d855}: '𝡕'
SignwritingHandDashOvalFiveFingersSpread\u{1d856}: '𝡖'
SignwritingHandDashFlatFiveFingersSpreadHinged\u{1d857}: '𝡗'
SignwritingHandDashFlatFiveFingersSpreadHingedThumbSide\u{1d858}: '𝡘'
SignwritingHandDashFlatFiveFingersSpreadHingedNoThumb\u{1d859}: '𝡙'
SignwritingHandDashFlat\u{1d85a}: '𝡚'
SignwritingHandDashFlatBetweenPalmFacings\u{1d85b}: '𝡛'
SignwritingHandDashFlatHeel\u{1d85c}: '𝡜'
SignwritingHandDashFlatThumbSide\u{1d85d}: '𝡝'
SignwritingHandDashFlatHeelThumbSide\u{1d85e}: '𝡞'
SignwritingHandDashFlatThumbBent\u{1d85f}: '𝡟'
SignwritingHandDashFlatThumbForward\u{1d860}: '𝡠'
SignwritingHandDashFlatSplitIndexThumbSide\u{1d861}: '𝡡'
SignwritingHandDashFlatSplitCentre\u{1d862}: '𝡢'
SignwritingHandDashFlatSplitCentreThumbSide\u{1d863}: '𝡣'
SignwritingHandDashFlatSplitCentreThumbSideBent\u{1d864}: '𝡤'
SignwritingHandDashFlatSplitLittle\u{1d865}: '𝡥'
SignwritingHandDashClaw\u{1d866}: '𝡦'
SignwritingHandDashClawThumbSide\u{1d867}: '𝡧'
SignwritingHandDashClawNoThumb\u{1d868}: '𝡨'
SignwritingHandDashClawThumbForward\u{1d869}: '𝡩'
SignwritingHandDashHookCurlicue\u{1d86a}: '𝡪'
SignwritingHandDashHook\u{1d86b}: '𝡫'
SignwritingHandDashCupOpen\u{1d86c}: '𝡬'
SignwritingHandDashCup\u{1d86d}: '𝡭'
SignwritingHandDashCupOpenThumbSide\u{1d86e}: '𝡮'
SignwritingHandDashCupThumbSide\u{1d86f}: '𝡯'
SignwritingHandDashCupOpenNoThumb\u{1d870}: '𝡰'
SignwritingHandDashCupNoThumb\u{1d871}: '𝡱'
SignwritingHandDashCupOpenThumbForward\u{1d872}: '𝡲'
SignwritingHandDashCupThumbForward\u{1d873}: '𝡳'
SignwritingHandDashCurlicueOpen\u{1d874}: '𝡴'
SignwritingHandDashCurlicue\u{1d875}: '𝡵'
SignwritingHandDashCircle\u{1d876}: '𝡶'
SignwritingHandDashOval\u{1d877}: '𝡷'
SignwritingHandDashOvalThumbSide\u{1d878}: '𝡸'
SignwritingHandDashOvalNoThumb\u{1d879}: '𝡹'
SignwritingHandDashOvalThumbForward\u{1d87a}: '𝡺'
SignwritingHandDashHingeOpen\u{1d87b}: '𝡻'
SignwritingHandDashHingeOpenThumbForward\u{1d87c}: '𝡼'
SignwritingHandDashHinge\u{1d87d}: '𝡽'
SignwritingHandDashHingeSmall\u{1d87e}: '𝡾'
SignwritingHandDashHingeOpenThumbSide\u{1d87f}: '𝡿'
SignwritingHandDashHingeThumbSide\u{1d880}: '𝢀'
SignwritingHandDashHingeOpenNoThumb\u{1d881}: '𝢁'
SignwritingHandDashHingeNoThumb\u{1d882}: '𝢂'
SignwritingHandDashHingeThumbSideTouchingIndex\u{1d883}: '𝢃'
SignwritingHandDashHingeThumbBetweenMiddleRing\u{1d884}: '𝢄'
SignwritingHandDashAngle\u{1d885}: '𝢅'
SignwritingHandDashFistIndexMiddleRing\u{1d886}: '𝢆'
SignwritingHandDashCircleIndexMiddleRing\u{1d887}: '𝢇'
SignwritingHandDashHingeIndexMiddleRing\u{1d888}: '𝢈'
SignwritingHandDashAngleIndexMiddleRing\u{1d889}: '𝢉'
SignwritingHandDashHingeLittle\u{1d88a}: '𝢊'
SignwritingHandDashFistIndexMiddleRingBent\u{1d88b}: '𝢋'
SignwritingHandDashFistIndexMiddleRingConjoined\u{1d88c}: '𝢌'
SignwritingHandDashHingeIndexMiddleRingConjoined\u{1d88d}: '𝢍'
SignwritingHandDashFistLittleDown\u{1d88e}: '𝢎'
SignwritingHandDashFistLittleDownRippleStraight\u{1d88f}: '𝢏'
SignwritingHandDashFistLittleDownRippleCurved\u{1d890}: '𝢐'
SignwritingHandDashFistLittleDownOthersCircled\u{1d891}: '𝢑'
SignwritingHandDashFistLittleUp\u{1d892}: '𝢒'
SignwritingHandDashFistThumbUnderLittleUp\u{1d893}: '𝢓'
SignwritingHandDashCircleLittleUp\u{1d894}: '𝢔'
SignwritingHandDashOvalLittleUp\u{1d895}: '𝢕'
SignwritingHandDashAngleLittleUp\u{1d896}: '𝢖'
SignwritingHandDashFistLittleRaisedKnuckle\u{1d897}: '𝢗'
SignwritingHandDashFistLittleBent\u{1d898}: '𝢘'
SignwritingHandDashFistLittleTouchesThumb\u{1d899}: '𝢙'
SignwritingHandDashFistLittleThumb\u{1d89a}: '𝢚'
SignwritingHandDashHingeLittleThumb\u{1d89b}: '𝢛'
SignwritingHandDashFistLittleIndexThumb\u{1d89c}: '𝢜'
SignwritingHandDashHingeLittleIndexThumb\u{1d89d}: '𝢝'
SignwritingHandDashAngleLittleIndexThumbIndexThumbOut\u{1d89e}: '𝢞'
SignwritingHandDashAngleLittleIndexThumbIndexThumb\u{1d89f}: '𝢟'
SignwritingHandDashFistLittleIndex\u{1d8a0}: '𝢠'
SignwritingHandDashCircleLittleIndex\u{1d8a1}: '𝢡'
SignwritingHandDashHingeLittleIndex\u{1d8a2}: '𝢢'
SignwritingHandDashAngleLittleIndex\u{1d8a3}: '𝢣'
SignwritingHandDashFistIndexMiddleLittle\u{1d8a4}: '𝢤'
SignwritingHandDashCircleIndexMiddleLittle\u{1d8a5}: '𝢥'
SignwritingHandDashHingeIndexMiddleLittle\u{1d8a6}: '𝢦'
SignwritingHandDashHingeRing\u{1d8a7}: '𝢧'
SignwritingHandDashAngleIndexMiddleLittle\u{1d8a8}: '𝢨'
SignwritingHandDashFistIndexMiddleCrossLittle\u{1d8a9}: '𝢩'
SignwritingHandDashCircleIndexMiddleCrossLittle\u{1d8aa}: '𝢪'
SignwritingHandDashFistRingDown\u{1d8ab}: '𝢫'
SignwritingHandDashHingeRingDownIndexThumbHookMiddle\u{1d8ac}: '𝢬'
SignwritingHandDashAngleRingDownMiddleThumbIndexCross\u{1d8ad}: '𝢭'
SignwritingHandDashFistRingUp\u{1d8ae}: '𝢮'
SignwritingHandDashFistRingRaisedKnuckle\u{1d8af}: '𝢯'
SignwritingHandDashFistRingLittle\u{1d8b0}: '𝢰'
SignwritingHandDashCircleRingLittle\u{1d8b1}: '𝢱'
SignwritingHandDashOvalRingLittle\u{1d8b2}: '𝢲'
SignwritingHandDashAngleRingLittle\u{1d8b3}: '𝢳'
SignwritingHandDashFistRingMiddle\u{1d8b4}: '𝢴'
SignwritingHandDashFistRingMiddleConjoined\u{1d8b5}: '𝢵'
SignwritingHandDashFistRingMiddleRaisedKnuckles\u{1d8b6}: '𝢶'
SignwritingHandDashFistRingIndex\u{1d8b7}: '𝢷'
SignwritingHandDashFistRingThumb\u{1d8b8}: '𝢸'
SignwritingHandDashHookRingThumb\u{1d8b9}: '𝢹'
SignwritingHandDashFistIndexRingLittle\u{1d8ba}: '𝢺'
SignwritingHandDashCircleIndexRingLittle\u{1d8bb}: '𝢻'
SignwritingHandDashCurlicueIndexRingLittleOn\u{1d8bc}: '𝢼'
SignwritingHandDashHookIndexRingLittleOut\u{1d8bd}: '𝢽'
SignwritingHandDashHookIndexRingLittleIn\u{1d8be}: '𝢾'
SignwritingHandDashHookIndexRingLittleUnder\u{1d8bf}: '𝢿'
SignwritingHandDashCupIndexRingLittle\u{1d8c0}: '𝣀'
SignwritingHandDashHingeIndexRingLittle\u{1d8c1}: '𝣁'
SignwritingHandDashAngleIndexRingLittleOut\u{1d8c2}: '𝣂'
SignwritingHandDashAngleIndexRingLittle\u{1d8c3}: '𝣃'
SignwritingHandDashFistMiddleDown\u{1d8c4}: '𝣄'
SignwritingHandDashHingeMiddle\u{1d8c5}: '𝣅'
SignwritingHandDashFistMiddleUp\u{1d8c6}: '𝣆'
SignwritingHandDashCircleMiddleUp\u{1d8c7}: '𝣇'
SignwritingHandDashFistMiddleRaisedKnuckle\u{1d8c8}: '𝣈'
SignwritingHandDashFistMiddleUpThumbSide\u{1d8c9}: '𝣉'
SignwritingHandDashHookMiddleThumb\u{1d8ca}: '𝣊'
SignwritingHandDashFistMiddleThumbLittle\u{1d8cb}: '𝣋'
SignwritingHandDashFistMiddleLittle\u{1d8cc}: '𝣌'
SignwritingHandDashFistMiddleRingLittle\u{1d8cd}: '𝣍'
SignwritingHandDashCircleMiddleRingLittle\u{1d8ce}: '𝣎'
SignwritingHandDashCurlicueMiddleRingLittleOn\u{1d8cf}: '𝣏'
SignwritingHandDashCupMiddleRingLittle\u{1d8d0}: '𝣐'
SignwritingHandDashHingeMiddleRingLittle\u{1d8d1}: '𝣑'
SignwritingHandDashAngleMiddleRingLittleOut\u{1d8d2}: '𝣒'
SignwritingHandDashAngleMiddleRingLittleIn\u{1d8d3}: '𝣓'
SignwritingHandDashAngleMiddleRingLittle\u{1d8d4}: '𝣔'
SignwritingHandDashCircleMiddleRingLittleBent\u{1d8d5}: '𝣕'
SignwritingHandDashClawMiddleRingLittleConjoined\u{1d8d6}: '𝣖'
SignwritingHandDashClawMiddleRingLittleConjoinedSide\u{1d8d7}: '𝣗'
SignwritingHandDashHookMiddleRingLittleConjoinedOut\u{1d8d8}: '𝣘'
SignwritingHandDashHookMiddleRingLittleConjoinedIn\u{1d8d9}: '𝣙'
SignwritingHandDashHookMiddleRingLittleConjoined\u{1d8da}: '𝣚'
SignwritingHandDashHingeIndexHinged\u{1d8db}: '𝣛'
SignwritingHandDashFistIndexThumbSide\u{1d8dc}: '𝣜'
SignwritingHandDashHingeIndexThumbSide\u{1d8dd}: '𝣝'
SignwritingHandDashFistIndexThumbSideThumbDiagonal\u{1d8de}: '𝣞'
SignwritingHandDashFistIndexThumbSideThumbConjoined\u{1d8df}: '𝣟'
SignwritingHandDashFistIndexThumbSideThumbBent\u{1d8e0}: '𝣠'
SignwritingHandDashFistIndexThumbSideIndexBent\u{1d8e1}: '𝣡'
SignwritingHandDashFistIndexThumbSideBothBent\u{1d8e2}: '𝣢'
SignwritingHandDashFistIndexThumbSideIndexHinge\u{1d8e3}: '𝣣'
SignwritingHandDashFistIndexThumbForwardIndexStraight\u{1d8e4}: '𝣤'
SignwritingHandDashFistIndexThumbForwardIndexBent\u{1d8e5}: '𝣥'
SignwritingHandDashFistIndexThumbHook\u{1d8e6}: '𝣦'
SignwritingHandDashFistIndexThumbCurlicue\u{1d8e7}: '𝣧'
SignwritingHandDashFistIndexThumbCurveThumbInside\u{1d8e8}: '𝣨'
SignwritingHandDashClawIndexThumbCurveThumbInside\u{1d8e9}: '𝣩'
SignwritingHandDashFistIndexThumbCurveThumbUnder\u{1d8ea}: '𝣪'
SignwritingHandDashFistIndexThumbCircle\u{1d8eb}: '𝣫'
SignwritingHandDashCupIndexThumb\u{1d8ec}: '𝣬'
SignwritingHandDashCupIndexThumbOpen\u{1d8ed}: '𝣭'
SignwritingHandDashHingeIndexThumbOpen\u{1d8ee}: '𝣮'
SignwritingHandDashHingeIndexThumbLarge\u{1d8ef}: '𝣯'
SignwritingHandDashHingeIndexThumb\u{1d8f0}: '𝣰'
SignwritingHandDashHingeIndexThumbSmall\u{1d8f1}: '𝣱'
SignwritingHandDashAngleIndexThumbOut\u{1d8f2}: '𝣲'
SignwritingHandDashAngleIndexThumbIn\u{1d8f3}: '𝣳'
SignwritingHandDashAngleIndexThumb\u{1d8f4}: '𝣴'
SignwritingHandDashFistThumb\u{1d8f5}: '𝣵'
SignwritingHandDashFistThumbHeel\u{1d8f6}: '𝣶'
SignwritingHandDashFistThumbSideDiagonal\u{1d8f7}: '𝣷'
SignwritingHandDashFistThumbSideConjoined\u{1d8f8}: '𝣸'
SignwritingHandDashFistThumbSideBent\u{1d8f9}: '𝣹'
SignwritingHandDashFistThumbForward\u{1d8fa}: '𝣺'
SignwritingHandDashFistThumbBetweenIndexMiddle\u{1d8fb}: '𝣻'
SignwritingHandDashFistThumbBetweenMiddleRing\u{1d8fc}: '𝣼'
SignwritingHandDashFistThumbBetweenRingLittle\u{1d8fd}: '𝣽'
SignwritingHandDashFistThumbUnderTwoFingers\u{1d8fe}: '𝣾'
SignwritingHandDashFistThumbOverTwoFingers\u{1d8ff}: '𝣿'
SignwritingHandDashFistThumbUnderThreeFingers\u{1d900}: '𝤀'
SignwritingHandDashFistThumbUnderFourFingers\u{1d901}: '𝤁'
SignwritingHandDashFistThumbOverFourRaisedKnuckles\u{1d902}: '𝤂'
SignwritingHandDashFist\u{1d903}: '𝤃'
SignwritingHandDashFistHeel\u{1d904}: '𝤄'
SignwritingTouchSingle\u{1d905}: '𝤅'
SignwritingTouchMultiple\u{1d906}: '𝤆'
SignwritingTouchBetween\u{1d907}: '𝤇'
SignwritingGraspSingle\u{1d908}: '𝤈'
SignwritingGraspMultiple\u{1d909}: '𝤉'
SignwritingGraspBetween\u{1d90a}: '𝤊'
SignwritingStrikeSingle\u{1d90b}: '𝤋'
SignwritingStrikeMultiple\u{1d90c}: '𝤌'
SignwritingStrikeBetween\u{1d90d}: '𝤍'
SignwritingBrushSingle\u{1d90e}: '𝤎'
SignwritingBrushMultiple\u{1d90f}: '𝤏'
SignwritingBrushBetween\u{1d910}: '𝤐'
SignwritingRubSingle\u{1d911}: '𝤑'
SignwritingRubMultiple\u{1d912}: '𝤒'
SignwritingRubBetween\u{1d913}: '𝤓'
SignwritingSurfaceSymbols\u{1d914}: '𝤔'
SignwritingSurfaceBetween\u{1d915}: '𝤕'
SignwritingSqueezeLargeSingle\u{1d916}: '𝤖'
SignwritingSqueezeSmallSingle\u{1d917}: '𝤗'
SignwritingSqueezeLargeMultiple\u{1d918}: '𝤘'
SignwritingSqueezeSmallMultiple\u{1d919}: '𝤙'
SignwritingSqueezeSequential\u{1d91a}: '𝤚'
SignwritingFlickLargeSingle\u{1d91b}: '𝤛'
SignwritingFlickSmallSingle\u{1d91c}: '𝤜'
SignwritingFlickLargeMultiple\u{1d91d}: '𝤝'
SignwritingFlickSmallMultiple\u{1d91e}: '𝤞'
SignwritingFlickSequential\u{1d91f}: '𝤟'
SignwritingSqueezeFlickAlternating\u{1d920}: '𝤠'
SignwritingMovementDashHingeUpDownLarge\u{1d921}: '𝤡'
SignwritingMovementDashHingeUpDownSmall\u{1d922}: '𝤢'
SignwritingMovementDashHingeUpSequential\u{1d923}: '𝤣'
SignwritingMovementDashHingeDownSequential\u{1d924}: '𝤤'
SignwritingMovementDashHingeUpDownAlternatingLarge\u{1d925}: '𝤥'
SignwritingMovementDashHingeUpDownAlternatingSmall\u{1d926}: '𝤦'
SignwritingMovementDashHingeSideToSideScissors\u{1d927}: '𝤧'
SignwritingMovementDashWallplaneFingerContact\u{1d928}: '𝤨'
SignwritingMovementDashFloorplaneFingerContact\u{1d929}: '𝤩'
SignwritingMovementDashWallplaneSingleStraightSmall\u{1d92a}: '𝤪'
SignwritingMovementDashWallplaneSingleStraightMedium\u{1d92b}: '𝤫'
SignwritingMovementDashWallplaneSingleStraightLarge\u{1d92c}: '𝤬'
SignwritingMovementDashWallplaneSingleStraightLargest\u{1d92d}: '𝤭'
SignwritingMovementDashWallplaneSingleWristFlex\u{1d92e}: '𝤮'
SignwritingMovementDashWallplaneDoubleStraight\u{1d92f}: '𝤯'
SignwritingMovementDashWallplaneDoubleWristFlex\u{1d930}: '𝤰'
SignwritingMovementDashWallplaneDoubleAlternating\u{1d931}: '𝤱'
SignwritingMovementDashWallplaneDoubleAlternatingWristFlex\u{1d932}: '𝤲'
SignwritingMovementDashWallplaneCross\u{1d933}: '𝤳'
SignwritingMovementDashWallplaneTripleStraightMovement\u{1d934}: '𝤴'
SignwritingMovementDashWallplaneTripleWristFlex\u{1d935}: '𝤵'
SignwritingMovementDashWallplaneTripleAlternating\u{1d936}: '𝤶'
SignwritingMovementDashWallplaneTripleAlternatingWristFlex\u{1d937}: '𝤷'
SignwritingMovementDashWallplaneBendSmall\u{1d938}: '𝤸'
SignwritingMovementDashWallplaneBendMedium\u{1d939}: '𝤹'
SignwritingMovementDashWallplaneBendLarge\u{1d93a}: '𝤺'
SignwritingMovementDashWallplaneCornerSmall\u{1d93b}: '𝤻'
SignwritingMovementDashWallplaneCornerMedium\u{1d93c}: '𝤼'
SignwritingMovementDashWallplaneCornerLarge\u{1d93d}: '𝤽'
SignwritingMovementDashWallplaneCornerRotation\u{1d93e}: '𝤾'
SignwritingMovementDashWallplaneCheckSmall\u{1d93f}: '𝤿'
SignwritingMovementDashWallplaneCheckMedium\u{1d940}: '𝥀'
SignwritingMovementDashWallplaneCheckLarge\u{1d941}: '𝥁'
SignwritingMovementDashWallplaneBoxSmall\u{1d942}: '𝥂'
SignwritingMovementDashWallplaneBoxMedium\u{1d943}: '𝥃'
SignwritingMovementDashWallplaneBoxLarge\u{1d944}: '𝥄'
SignwritingMovementDashWallplaneZigzagSmall\u{1d945}: '𝥅'
SignwritingMovementDashWallplaneZigzagMedium\u{1d946}: '𝥆'
SignwritingMovementDashWallplaneZigzagLarge\u{1d947}: '𝥇'
SignwritingMovementDashWallplanePeaksSmall\u{1d948}: '𝥈'
SignwritingMovementDashWallplanePeaksMedium\u{1d949}: '𝥉'
SignwritingMovementDashWallplanePeaksLarge\u{1d94a}: '𝥊'
SignwritingTravelDashWallplaneRotationDashWallplaneSingle\u{1d94b}: '𝥋'
SignwritingTravelDashWallplaneRotationDashWallplaneDouble\u{1d94c}: '𝥌'
SignwritingTravelDashWallplaneRotationDashWallplaneAlternating\u{1d94d}: '𝥍'
SignwritingTravelDashWallplaneRotationDashFloorplaneSingle\u{1d94e}: '𝥎'
SignwritingTravelDashWallplaneRotationDashFloorplaneDouble\u{1d94f}: '𝥏'
SignwritingTravelDashWallplaneRotationDashFloorplaneAlternating\u{1d950}: '𝥐'
SignwritingTravelDashWallplaneShaking\u{1d951}: '𝥑'
SignwritingTravelDashWallplaneArmSpiralSingle\u{1d952}: '𝥒'
SignwritingTravelDashWallplaneArmSpiralDouble\u{1d953}: '𝥓'
SignwritingTravelDashWallplaneArmSpiralTriple\u{1d954}: '𝥔'
SignwritingMovementDashDiagonalAwaySmall\u{1d955}: '𝥕'
SignwritingMovementDashDiagonalAwayMedium\u{1d956}: '𝥖'
SignwritingMovementDashDiagonalAwayLarge\u{1d957}: '𝥗'
SignwritingMovementDashDiagonalAwayLargest\u{1d958}: '𝥘'
SignwritingMovementDashDiagonalTowardsSmall\u{1d959}: '𝥙'
SignwritingMovementDashDiagonalTowardsMedium\u{1d95a}: '𝥚'
SignwritingMovementDashDiagonalTowardsLarge\u{1d95b}: '𝥛'
SignwritingMovementDashDiagonalTowardsLargest\u{1d95c}: '𝥜'
SignwritingMovementDashDiagonalBetweenAwaySmall\u{1d95d}: '𝥝'
SignwritingMovementDashDiagonalBetweenAwayMedium\u{1d95e}: '𝥞'
SignwritingMovementDashDiagonalBetweenAwayLarge\u{1d95f}: '𝥟'
SignwritingMovementDashDiagonalBetweenAwayLargest\u{1d960}: '𝥠'
SignwritingMovementDashDiagonalBetweenTowardsSmall\u{1d961}: '𝥡'
SignwritingMovementDashDiagonalBetweenTowardsMedium\u{1d962}: '𝥢'
SignwritingMovementDashDiagonalBetweenTowardsLarge\u{1d963}: '𝥣'
SignwritingMovementDashDiagonalBetweenTowardsLargest\u{1d964}: '𝥤'
SignwritingMovementDashFloorplaneSingleStraightSmall\u{1d965}: '𝥥'
SignwritingMovementDashFloorplaneSingleStraightMedium\u{1d966}: '𝥦'
SignwritingMovementDashFloorplaneSingleStraightLarge\u{1d967}: '𝥧'
SignwritingMovementDashFloorplaneSingleStraightLargest\u{1d968}: '𝥨'
SignwritingMovementDashFloorplaneSingleWristFlex\u{1d969}: '𝥩'
SignwritingMovementDashFloorplaneDoubleStraight\u{1d96a}: '𝥪'
SignwritingMovementDashFloorplaneDoubleWristFlex\u{1d96b}: '𝥫'
SignwritingMovementDashFloorplaneDoubleAlternating\u{1d96c}: '𝥬'
SignwritingMovementDashFloorplaneDoubleAlternatingWristFlex\u{1d96d}: '𝥭'
SignwritingMovementDashFloorplaneCross\u{1d96e}: '𝥮'
SignwritingMovementDashFloorplaneTripleStraightMovement\u{1d96f}: '𝥯'
SignwritingMovementDashFloorplaneTripleWristFlex\u{1d970}: '𝥰'
SignwritingMovementDashFloorplaneTripleAlternatingMovement\u{1d971}: '𝥱'
SignwritingMovementDashFloorplaneTripleAlternatingWristFlex\u{1d972}: '𝥲'
SignwritingMovementDashFloorplaneBend\u{1d973}: '𝥳'
SignwritingMovementDashFloorplaneCornerSmall\u{1d974}: '𝥴'
SignwritingMovementDashFloorplaneCornerMedium\u{1d975}: '𝥵'
SignwritingMovementDashFloorplaneCornerLarge\u{1d976}: '𝥶'
SignwritingMovementDashFloorplaneCheck\u{1d977}: '𝥷'
SignwritingMovementDashFloorplaneBoxSmall\u{1d978}: '𝥸'
SignwritingMovementDashFloorplaneBoxMedium\u{1d979}: '𝥹'
SignwritingMovementDashFloorplaneBoxLarge\u{1d97a}: '𝥺'
SignwritingMovementDashFloorplaneZigzagSmall\u{1d97b}: '𝥻'
SignwritingMovementDashFloorplaneZigzagMedium\u{1d97c}: '𝥼'
SignwritingMovementDashFloorplaneZigzagLarge\u{1d97d}: '𝥽'
SignwritingMovementDashFloorplanePeaksSmall\u{1d97e}: '𝥾'
SignwritingMovementDashFloorplanePeaksMedium\u{1d97f}: '𝥿'
SignwritingMovementDashFloorplanePeaksLarge\u{1d980}: '𝦀'
SignwritingTravelDashFloorplaneRotationDashFloorplaneSingle\u{1d981}: '𝦁'
SignwritingTravelDashFloorplaneRotationDashFloorplaneDouble\u{1d982}: '𝦂'
SignwritingTravelDashFloorplaneRotationDashFloorplaneAlternating\u{1d983}: '𝦃'
SignwritingTravelDashFloorplaneRotationDashWallplaneSingle\u{1d984}: '𝦄'
SignwritingTravelDashFloorplaneRotationDashWallplaneDouble\u{1d985}: '𝦅'
SignwritingTravelDashFloorplaneRotationDashWallplaneAlternating\u{1d986}: '𝦆'
SignwritingTravelDashFloorplaneShaking\u{1d987}: '𝦇'
SignwritingMovementDashWallplaneCurveQuarterSmall\u{1d988}: '𝦈'
SignwritingMovementDashWallplaneCurveQuarterMedium\u{1d989}: '𝦉'
SignwritingMovementDashWallplaneCurveQuarterLarge\u{1d98a}: '𝦊'
SignwritingMovementDashWallplaneCurveQuarterLargest\u{1d98b}: '𝦋'
SignwritingMovementDashWallplaneCurveHalfDashCircleSmall\u{1d98c}: '𝦌'
SignwritingMovementDashWallplaneCurveHalfDashCircleMedium\u{1d98d}: '𝦍'
SignwritingMovementDashWallplaneCurveHalfDashCircleLarge\u{1d98e}: '𝦎'
SignwritingMovementDashWallplaneCurveHalfDashCircleLargest\u{1d98f}: '𝦏'
SignwritingMovementDashWallplaneCurveThreeDashQuarterCircleSmall\u{1d990}: '𝦐'
SignwritingMovementDashWallplaneCurveThreeDashQuarterCircleMedium\u{1d991}: '𝦑'
SignwritingMovementDashWallplaneHumpSmall\u{1d992}: '𝦒'
SignwritingMovementDashWallplaneHumpMedium\u{1d993}: '𝦓'
SignwritingMovementDashWallplaneHumpLarge\u{1d994}: '𝦔'
SignwritingMovementDashWallplaneLoopSmall\u{1d995}: '𝦕'
SignwritingMovementDashWallplaneLoopMedium\u{1d996}: '𝦖'
SignwritingMovementDashWallplaneLoopLarge\u{1d997}: '𝦗'
SignwritingMovementDashWallplaneLoopSmallDouble\u{1d998}: '𝦘'
SignwritingMovementDashWallplaneWaveCurveDoubleSmall\u{1d999}: '𝦙'
SignwritingMovementDashWallplaneWaveCurveDoubleMedium\u{1d99a}: '𝦚'
SignwritingMovementDashWallplaneWaveCurveDoubleLarge\u{1d99b}: '𝦛'
SignwritingMovementDashWallplaneWaveCurveTripleSmall\u{1d99c}: '𝦜'
SignwritingMovementDashWallplaneWaveCurveTripleMedium\u{1d99d}: '𝦝'
SignwritingMovementDashWallplaneWaveCurveTripleLarge\u{1d99e}: '𝦞'
SignwritingMovementDashWallplaneCurveThenStraight\u{1d99f}: '𝦟'
SignwritingMovementDashWallplaneCurvedCrossSmall\u{1d9a0}: '𝦠'
SignwritingMovementDashWallplaneCurvedCrossMedium\u{1d9a1}: '𝦡'
SignwritingRotationDashWallplaneSingle\u{1d9a2}: '𝦢'
SignwritingRotationDashWallplaneDouble\u{1d9a3}: '𝦣'
SignwritingRotationDashWallplaneAlternate\u{1d9a4}: '𝦤'
SignwritingMovementDashWallplaneShaking\u{1d9a5}: '𝦥'
SignwritingMovementDashWallplaneCurveHittingFrontWall\u{1d9a6}: '𝦦'
SignwritingMovementDashWallplaneHumpHittingFrontWall\u{1d9a7}: '𝦧'
SignwritingMovementDashWallplaneLoopHittingFrontWall\u{1d9a8}: '𝦨'
SignwritingMovementDashWallplaneWaveHittingFrontWall\u{1d9a9}: '𝦩'
SignwritingRotationDashWallplaneSingleHittingFrontWall\u{1d9aa}: '𝦪'
SignwritingRotationDashWallplaneDoubleHittingFrontWall\u{1d9ab}: '𝦫'
SignwritingRotationDashWallplaneAlternatingHittingFrontWall\u{1d9ac}: '𝦬'
SignwritingMovementDashWallplaneCurveHittingChest\u{1d9ad}: '𝦭'
SignwritingMovementDashWallplaneHumpHittingChest\u{1d9ae}: '𝦮'
SignwritingMovementDashWallplaneLoopHittingChest\u{1d9af}: '𝦯'
SignwritingMovementDashWallplaneWaveHittingChest\u{1d9b0}: '𝦰'
SignwritingRotationDashWallplaneSingleHittingChest\u{1d9b1}: '𝦱'
SignwritingRotationDashWallplaneDoubleHittingChest\u{1d9b2}: '𝦲'
SignwritingRotationDashWallplaneAlternatingHittingChest\u{1d9b3}: '𝦳'
SignwritingMovementDashWallplaneWaveDiagonalPathSmall\u{1d9b4}: '𝦴'
SignwritingMovementDashWallplaneWaveDiagonalPathMedium\u{1d9b5}: '𝦵'
SignwritingMovementDashWallplaneWaveDiagonalPathLarge\u{1d9b6}: '𝦶'
SignwritingMovementDashFloorplaneCurveHittingCeilingSmall\u{1d9b7}: '𝦷'
SignwritingMovementDashFloorplaneCurveHittingCeilingLarge\u{1d9b8}: '𝦸'
SignwritingMovementDashFloorplaneHumpHittingCeilingSmallDouble\u{1d9b9}: '𝦹'
SignwritingMovementDashFloorplaneHumpHittingCeilingLargeDouble\u{1d9ba}: '𝦺'
SignwritingMovementDashFloorplaneHumpHittingCeilingSmallTriple\u{1d9bb}: '𝦻'
SignwritingMovementDashFloorplaneHumpHittingCeilingLargeTriple\u{1d9bc}: '𝦼'
SignwritingMovementDashFloorplaneLoopHittingCeilingSmallSingle\u{1d9bd}: '𝦽'
SignwritingMovementDashFloorplaneLoopHittingCeilingLargeSingle\u{1d9be}: '𝦾'
SignwritingMovementDashFloorplaneLoopHittingCeilingSmallDouble\u{1d9bf}: '𝦿'
SignwritingMovementDashFloorplaneLoopHittingCeilingLargeDouble\u{1d9c0}: '𝧀'
SignwritingMovementDashFloorplaneWaveHittingCeilingSmall\u{1d9c1}: '𝧁'
SignwritingMovementDashFloorplaneWaveHittingCeilingLarge\u{1d9c2}: '𝧂'
SignwritingRotationDashFloorplaneSingleHittingCeiling\u{1d9c3}: '𝧃'
SignwritingRotationDashFloorplaneDoubleHittingCeiling\u{1d9c4}: '𝧄'
SignwritingRotationDashFloorplaneAlternatingHittingCeiling\u{1d9c5}: '𝧅'
SignwritingMovementDashFloorplaneCurveHittingFloorSmall\u{1d9c6}: '𝧆'
SignwritingMovementDashFloorplaneCurveHittingFloorLarge\u{1d9c7}: '𝧇'
SignwritingMovementDashFloorplaneHumpHittingFloorSmallDouble\u{1d9c8}: '𝧈'
SignwritingMovementDashFloorplaneHumpHittingFloorLargeDouble\u{1d9c9}: '𝧉'
SignwritingMovementDashFloorplaneHumpHittingFloorTripleSmallTriple\u{1d9ca}: '𝧊'
SignwritingMovementDashFloorplaneHumpHittingFloorTripleLargeTriple\u{1d9cb}: '𝧋'
SignwritingMovementDashFloorplaneLoopHittingFloorSmallSingle\u{1d9cc}: '𝧌'
SignwritingMovementDashFloorplaneLoopHittingFloorLargeSingle\u{1d9cd}: '𝧍'
SignwritingMovementDashFloorplaneLoopHittingFloorSmallDouble\u{1d9ce}: '𝧎'
SignwritingMovementDashFloorplaneLoopHittingFloorLargeDouble\u{1d9cf}: '𝧏'
SignwritingMovementDashFloorplaneWaveHittingFloorSmall\u{1d9d0}: '𝧐'
SignwritingMovementDashFloorplaneWaveHittingFloorLarge\u{1d9d1}: '𝧑'
SignwritingRotationDashFloorplaneSingleHittingFloor\u{1d9d2}: '𝧒'
SignwritingRotationDashFloorplaneDoubleHittingFloor\u{1d9d3}: '𝧓'
SignwritingRotationDashFloorplaneAlternatingHittingFloor\u{1d9d4}: '𝧔'
SignwritingMovementDashFloorplaneCurveSmall\u{1d9d5}: '𝧕'
SignwritingMovementDashFloorplaneCurveMedium\u{1d9d6}: '𝧖'
SignwritingMovementDashFloorplaneCurveLarge\u{1d9d7}: '𝧗'
SignwritingMovementDashFloorplaneCurveLargest\u{1d9d8}: '𝧘'
SignwritingMovementDashFloorplaneCurveCombined\u{1d9d9}: '𝧙'
SignwritingMovementDashFloorplaneHumpSmall\u{1d9da}: '𝧚'
SignwritingMovementDashFloorplaneLoopSmall\u{1d9db}: '𝧛'
SignwritingMovementDashFloorplaneWaveSnake\u{1d9dc}: '𝧜'
SignwritingMovementDashFloorplaneWaveSmall\u{1d9dd}: '𝧝'
SignwritingMovementDashFloorplaneWaveLarge\u{1d9de}: '𝧞'
SignwritingRotationDashFloorplaneSingle\u{1d9df}: '𝧟'
SignwritingRotationDashFloorplaneDouble\u{1d9e0}: '𝧠'
SignwritingRotationDashFloorplaneAlternating\u{1d9e1}: '𝧡'
SignwritingMovementDashFloorplaneShakingParallel\u{1d9e2}: '𝧢'
SignwritingMovementDashWallplaneArmCircleSmallSingle\u{1d9e3}: '𝧣'
SignwritingMovementDashWallplaneArmCircleMediumSingle\u{1d9e4}: '𝧤'
SignwritingMovementDashWallplaneArmCircleSmallDouble\u{1d9e5}: '𝧥'
SignwritingMovementDashWallplaneArmCircleMediumDouble\u{1d9e6}: '𝧦'
SignwritingMovementDashFloorplaneArmCircleHittingWallSmallSingle\u{1d9e7}: '𝧧'
SignwritingMovementDashFloorplaneArmCircleHittingWallMediumSingle\u{1d9e8}: '𝧨'
SignwritingMovementDashFloorplaneArmCircleHittingWallLargeSingle\u{1d9e9}: '𝧩'
SignwritingMovementDashFloorplaneArmCircleHittingWallSmallDouble\u{1d9ea}: '𝧪'
SignwritingMovementDashFloorplaneArmCircleHittingWallMediumDouble\u{1d9eb}: '𝧫'
SignwritingMovementDashFloorplaneArmCircleHittingWallLargeDouble\u{1d9ec}: '𝧬'
SignwritingMovementDashWallplaneWristCircleFrontSingle\u{1d9ed}: '𝧭'
SignwritingMovementDashWallplaneWristCircleFrontDouble\u{1d9ee}: '𝧮'
SignwritingMovementDashFloorplaneWristCircleHittingWallSingle\u{1d9ef}: '𝧯'
SignwritingMovementDashFloorplaneWristCircleHittingWallDouble\u{1d9f0}: '𝧰'
SignwritingMovementDashWallplaneFingerCirclesSingle\u{1d9f1}: '𝧱'
SignwritingMovementDashWallplaneFingerCirclesDouble\u{1d9f2}: '𝧲'
SignwritingMovementDashFloorplaneFingerCirclesHittingWallSingle\u{1d9f3}: '𝧳'
SignwritingMovementDashFloorplaneFingerCirclesHittingWallDouble\u{1d9f4}: '𝧴'
SignwritingDynamicArrowheadSmall\u{1d9f5}: '𝧵'
SignwritingDynamicArrowheadLarge\u{1d9f6}: '𝧶'
SignwritingDynamicFast\u{1d9f7}: '𝧷'
SignwritingDynamicSlow\u{1d9f8}: '𝧸'
SignwritingDynamicTense\u{1d9f9}: '𝧹'
SignwritingDynamicRelaxed\u{1d9fa}: '𝧺'
SignwritingDynamicSimultaneous\u{1d9fb}: '𝧻'
SignwritingDynamicSimultaneousAlternating\u{1d9fc}: '𝧼'
SignwritingDynamicEveryOtherTime\u{1d9fd}: '𝧽'
SignwritingDynamicGradual\u{1d9fe}: '𝧾'
SignwritingHead\u{1d9ff}: '𝧿'
SignwritingHeadRim\u{1da00}: '𝨀'
SignwritingHeadMovementDashWallplaneStraight\u{1da01}: '𝨁'
SignwritingHeadMovementDashWallplaneTilt\u{1da02}: '𝨂'
SignwritingHeadMovementDashFloorplaneStraight\u{1da03}: '𝨃'
SignwritingHeadMovementDashWallplaneCurve\u{1da04}: '𝨄'
SignwritingHeadMovementDashFloorplaneCurve\u{1da05}: '𝨅'
SignwritingHeadMovementCircle\u{1da06}: '𝨆'
SignwritingFaceDirectionPositionNoseForwardTilting\u{1da07}: '𝨇'
SignwritingFaceDirectionPositionNoseUpOrDown\u{1da08}: '𝨈'
SignwritingFaceDirectionPositionNoseUpOrDownTilting\u{1da09}: '𝨉'
SignwritingEyebrowsStraightUp\u{1da0a}: '𝨊'
SignwritingEyebrowsStraightNeutral\u{1da0b}: '𝨋'
SignwritingEyebrowsStraightDown\u{1da0c}: '𝨌'
SignwritingDreamyEyebrowsNeutralDown\u{1da0d}: '𝨍'
SignwritingDreamyEyebrowsDownNeutral\u{1da0e}: '𝨎'
SignwritingDreamyEyebrowsUpNeutral\u{1da0f}: '𝨏'
SignwritingDreamyEyebrowsNeutralUp\u{1da10}: '𝨐'
SignwritingForeheadNeutral\u{1da11}: '𝨑'
SignwritingForeheadContact\u{1da12}: '𝨒'
SignwritingForeheadWrinkled\u{1da13}: '𝨓'
SignwritingEyesOpen\u{1da14}: '𝨔'
SignwritingEyesSqueezed\u{1da15}: '𝨕'
SignwritingEyesClosed\u{1da16}: '𝨖'
SignwritingEyeBlinkSingle\u{1da17}: '𝨗'
SignwritingEyeBlinkMultiple\u{1da18}: '𝨘'
SignwritingEyesHalfOpen\u{1da19}: '𝨙'
SignwritingEyesWideOpen\u{1da1a}: '𝨚'
SignwritingEyesHalfClosed\u{1da1b}: '𝨛'
SignwritingEyesWideningMovement\u{1da1c}: '𝨜'
SignwritingEyeWink\u{1da1d}: '𝨝'
SignwritingEyelashesUp\u{1da1e}: '𝨞'
SignwritingEyelashesDown\u{1da1f}: '𝨟'
SignwritingEyelashesFluttering\u{1da20}: '𝨠'
SignwritingEyegazeDashWallplaneStraight\u{1da21}: '𝨡'
SignwritingEyegazeDashWallplaneStraightDouble\u{1da22}: '𝨢'
SignwritingEyegazeDashWallplaneStraightAlternating\u{1da23}: '𝨣'
SignwritingEyegazeDashFloorplaneStraight\u{1da24}: '𝨤'
SignwritingEyegazeDashFloorplaneStraightDouble\u{1da25}: '𝨥'
SignwritingEyegazeDashFloorplaneStraightAlternating\u{1da26}: '𝨦'
SignwritingEyegazeDashWallplaneCurved\u{1da27}: '𝨧'
SignwritingEyegazeDashFloorplaneCurved\u{1da28}: '𝨨'
SignwritingEyegazeDashWallplaneCircling\u{1da29}: '𝨩'
SignwritingCheeksPuffed\u{1da2a}: '𝨪'
SignwritingCheeksNeutral\u{1da2b}: '𝨫'
SignwritingCheeksSucked\u{1da2c}: '𝨬'
SignwritingTenseCheeksHigh\u{1da2d}: '𝨭'
SignwritingTenseCheeksMiddle\u{1da2e}: '𝨮'
SignwritingTenseCheeksLow\u{1da2f}: '𝨯'
SignwritingEars\u{1da30}: '𝨰'
SignwritingNoseNeutral\u{1da31}: '𝨱'
SignwritingNoseContact\u{1da32}: '𝨲'
SignwritingNoseWrinkles\u{1da33}: '𝨳'
SignwritingNoseWiggles\u{1da34}: '𝨴'
SignwritingAirBlowingOut\u{1da35}: '𝨵'
SignwritingAirSuckingIn\u{1da36}: '𝨶'
SignwritingAirBlowSmallRotations\u{1da37}: '𝨷'
SignwritingAirSuckSmallRotations\u{1da38}: '𝨸'
SignwritingBreathInhale\u{1da39}: '𝨹'
SignwritingBreathExhale\u{1da3a}: '𝨺'
SignwritingMouthClosedNeutral\u{1da3b}: '𝨻'
SignwritingMouthClosedForward\u{1da3c}: '𝨼'
SignwritingMouthClosedContact\u{1da3d}: '𝨽'
SignwritingMouthSmile\u{1da3e}: '𝨾'
SignwritingMouthSmileWrinkled\u{1da3f}: '𝨿'
SignwritingMouthSmileOpen\u{1da40}: '𝩀'
SignwritingMouthFrown\u{1da41}: '𝩁'
SignwritingMouthFrownWrinkled\u{1da42}: '𝩂'
SignwritingMouthFrownOpen\u{1da43}: '𝩃'
SignwritingMouthOpenCircle\u{1da44}: '𝩄'
SignwritingMouthOpenForward\u{1da45}: '𝩅'
SignwritingMouthOpenWrinkled\u{1da46}: '𝩆'
SignwritingMouthOpenOval\u{1da47}: '𝩇'
SignwritingMouthOpenOvalWrinkled\u{1da48}: '𝩈'
SignwritingMouthOpenOvalYawn\u{1da49}: '𝩉'
SignwritingMouthOpenRectangle\u{1da4a}: '𝩊'
SignwritingMouthOpenRectangleWrinkled\u{1da4b}: '𝩋'
SignwritingMouthOpenRectangleYawn\u{1da4c}: '𝩌'
SignwritingMouthKiss\u{1da4d}: '𝩍'
SignwritingMouthKissForward\u{1da4e}: '𝩎'
SignwritingMouthKissWrinkled\u{1da4f}: '𝩏'
SignwritingMouthTense\u{1da50}: '𝩐'
SignwritingMouthTenseForward\u{1da51}: '𝩑'
SignwritingMouthTenseSucked\u{1da52}: '𝩒'
SignwritingLipsPressedTogether\u{1da53}: '𝩓'
SignwritingLipLowerOverUpper\u{1da54}: '𝩔'
SignwritingLipUpperOverLower\u{1da55}: '𝩕'
SignwritingMouthCorners\u{1da56}: '𝩖'
SignwritingMouthWrinklesSingle\u{1da57}: '𝩗'
SignwritingMouthWrinklesDouble\u{1da58}: '𝩘'
SignwritingTongueStickingOutFar\u{1da59}: '𝩙'
SignwritingTongueLickingLips\u{1da5a}: '𝩚'
SignwritingTongueTipBetweenLips\u{1da5b}: '𝩛'
SignwritingTongueTipTouchingInsideMouth\u{1da5c}: '𝩜'
SignwritingTongueInsideMouthRelaxed\u{1da5d}: '𝩝'
SignwritingTongueMovesAgainstCheek\u{1da5e}: '𝩞'
SignwritingTongueCentreStickingOut\u{1da5f}: '𝩟'
SignwritingTongueCentreInsideMouth\u{1da60}: '𝩠'
SignwritingTeeth\u{1da61}: '𝩡'
SignwritingTeethMovement\u{1da62}: '𝩢'
SignwritingTeethOnTongue\u{1da63}: '𝩣'
SignwritingTeethOnTongueMovement\u{1da64}: '𝩤'
SignwritingTeethOnLips\u{1da65}: '𝩥'
SignwritingTeethOnLipsMovement\u{1da66}: '𝩦'
SignwritingTeethBiteLips\u{1da67}: '𝩧'
SignwritingMovementDashWallplaneJaw\u{1da68}: '𝩨'
SignwritingMovementDashFloorplaneJaw\u{1da69}: '𝩩'
SignwritingNeck\u{1da6a}: '𝩪'
SignwritingHair\u{1da6b}: '𝩫'
SignwritingExcitement\u{1da6c}: '𝩬'
SignwritingShoulderHipSpine\u{1da6d}: '𝩭'
SignwritingShoulderHipPositions\u{1da6e}: '𝩮'
SignwritingWallplaneShoulderHipMove\u{1da6f}: '𝩯'
SignwritingFloorplaneShoulderHipMove\u{1da70}: '𝩰'
SignwritingShoulderTiltingFromWaist\u{1da71}: '𝩱'
SignwritingTorsoDashWallplaneStraightStretch\u{1da72}: '𝩲'
SignwritingTorsoDashWallplaneCurvedBend\u{1da73}: '𝩳'
SignwritingTorsoDashFloorplaneTwisting\u{1da74}: '𝩴'
SignwritingUpperBodyTiltingFromHipJoints\u{1da75}: '𝩵'
SignwritingLimbCombination\u{1da76}: '𝩶'
SignwritingLimbLengthDash1\u{1da77}: '𝩷'
SignwritingLimbLengthDash2\u{1da78}: '𝩸'
SignwritingLimbLengthDash3\u{1da79}: '𝩹'
SignwritingLimbLengthDash4\u{1da7a}: '𝩺'
SignwritingLimbLengthDash5\u{1da7b}: '𝩻'
SignwritingLimbLengthDash6\u{1da7c}: '𝩼'
SignwritingLimbLengthDash7\u{1da7d}: '𝩽'
SignwritingFinger\u{1da7e}: '𝩾'
SignwritingLocationDashWallplaneSpace\u{1da7f}: '𝩿'
SignwritingLocationDashFloorplaneSpace\u{1da80}: '𝪀'
SignwritingLocationHeight\u{1da81}: '𝪁'
SignwritingLocationWidth\u{1da82}: '𝪂'
SignwritingLocationDepth\u{1da83}: '𝪃'
SignwritingLocationHeadNeck\u{1da84}: '𝪄'
SignwritingLocationTorso\u{1da85}: '𝪅'
SignwritingLocationLimbsDigits\u{1da86}: '𝪆'
SignwritingComma\u{1da87}: '𝪇'
SignwritingFullStop\u{1da88}: '𝪈'
SignwritingSemicolon\u{1da89}: '𝪉'
SignwritingColon\u{1da8a}: '𝪊'
SignwritingParenthesis\u{1da8b}: '𝪋'
SignwritingFillModifierDash2\u{1da9b}: '𝪛'
SignwritingFillModifierDash3\u{1da9c}: '𝪜'
SignwritingFillModifierDash4\u{1da9d}: '𝪝'
SignwritingFillModifierDash5\u{1da9e}: '𝪞'
SignwritingFillModifierDash6\u{1da9f}: '𝪟'
SignwritingRotationModifierDash2\u{1daa1}: '𝪡'
SignwritingRotationModifierDash3\u{1daa2}: '𝪢'
SignwritingRotationModifierDash4\u{1daa3}: '𝪣'
SignwritingRotationModifierDash5\u{1daa4}: '𝪤'
SignwritingRotationModifierDash6\u{1daa5}: '𝪥'
SignwritingRotationModifierDash7\u{1daa6}: '𝪦'
SignwritingRotationModifierDash8\u{1daa7}: '𝪧'
SignwritingRotationModifierDash9\u{1daa8}: '𝪨'
SignwritingRotationModifierDash10\u{1daa9}: '𝪩'
SignwritingRotationModifierDash11\u{1daaa}: '𝪪'
SignwritingRotationModifierDash12\u{1daab}: '𝪫'
SignwritingRotationModifierDash13\u{1daac}: '𝪬'
SignwritingRotationModifierDash14\u{1daad}: '𝪭'
SignwritingRotationModifierDash15\u{1daae}: '𝪮'
Methods
impl SuttonSignWriting[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case